/***********************************************************
 * $Id: InvalidExpressionSyntaxException.java 87 2007-12-17 01:06:40Z lech $
 * 
 * Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: Feb 28, 2007
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.util.comparators;

/**
 * This exception is thrown, whever the syntax of a comparator expression is invalid.
 * 
 * @author wglas
 */
public class InvalidExpressionSyntaxException extends Exception {

    private static final long serialVersionUID = 5143298409365161617L;
    
    private String expression;
    
    /**
     * @param expression The expression which caused the exception.
     * @see Exception#Exception()
     */
    public InvalidExpressionSyntaxException(String expression) {
        super();
        this.expression = expression;
    }

    /**
     * @param msg The error message.
     * @param e The cause of the error.
     * @param expression The expression which caused the exception.
     * 
     * @see Exception#Exception(String, Throwable)
     */
    public InvalidExpressionSyntaxException(String expression, String msg, Throwable e) {
        super(msg, e);
        this.expression = expression;
     }

    /**
     * @param expression The expression which caused the exception.
     * @param msg The error message.
     * 
     * @see Exception#Exception(String)
     */
    public InvalidExpressionSyntaxException(String expression, String msg) {
        super(msg);
        this.expression = expression;
    }

    /**
     * @param expression The expression which caused the exception.
     * @param e The cause of the error.
     * 
     * @see Exception#Exception(Throwable)
     */
    public InvalidExpressionSyntaxException(String expression, Throwable e) {
        super(e);
        this.expression = expression;
    }

    /**
     * @return The expression that caused the exception.
     */
    public String getExpression() {
        return this.expression;
    }

    /* (non-Javadoc)
     * @see java.lang.Throwable#getMessage()
     */
    @Override
    public String getMessage() {
        return "[" + this.expression + "]:" + super.getMessage();
    }

    /* (non-Javadoc)
     * @see java.lang.Throwable#getLocalizedMessage()
     */
    @Override
    public String getLocalizedMessage() {
        return "[" + this.expression + "]:" + super.getLocalizedMessage();
    }

}
