/***********************************************************
 * $Id: IPAddressType.java 87 2007-12-17 01:06:40Z lech $
 * 
 * Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 2006-03-13
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.util.net;


/**
 * Describes the "nature" of an IP address stored in a string or long.
 * It is dedicated to allow a few semantic checks, e.g. 
 * IPv4 netmasks have only 1s and than only 0s. 
 * Someday we might support IPv6 addresses.
 * 
 * @author lech
 */
public enum IPAddressType {
 
  /**
   * 4 byte Dotted IPv4 address, first an last byte must be non-zero. 
   */
  IPv4Address,
  
  /**
   * Like IPv4Address, but may be 0.0.0.0
   */
  IPv4ListenAddress,

  /**
   * 4 byte Dotted IPv4 netmask. constists of n set bits + 32-n unset bits. 
   */
  IPv4Netmask,
  
  /**
   * 4 byte Dotted IPv4 network address. first byte must be non-zero, last byte must be <255 
   */
  IPv4Network
  
  
}
