/***********************************************************
 * $Id: FieldAccessor.java 4 2006-12-26 19:16:57Z wglas $
 * 
 * Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 2006-03-13
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/


package org.clazzes.util.sec;

import java.util.Random;

/** 
 * A view [Password]Hasher helpers center
 * 
 * For usage, see classes Hasher and PersonOperations
 */
public class HashTools
{

	/**
	 * The recommended default salt length.
     * But be warned, the best known and widely used crypt algorithm uses a 2 char salt only.
	 */
	public static final byte DEFAULT_SALTLENGTH = 4;

	public static Random randomizer;

	/**
	 * @return a random salt with the default salt length.
	 */
	public static String randomSalt()
	{
		return randomSalt(DEFAULT_SALTLENGTH);
	}

	/**
     * Creates a random salt with the given length.
	 * @param length the wanted length of the salt. must be > 0 and <= 256.
	 * @return the random salt
	 */
	public static synchronized String randomSalt(int length)
	{
        if (length <= 0 || length > 256)
            throw new RuntimeException("HashTools.randomSalt("+length+"): Illegal length "+length);
		String saltChars = "1234567890abcdefghijklmnpqrstuvwxABCDEFGHIJKLMNPQRSTUVWX";
		long now = System.currentTimeMillis();
		if (randomizer == null)
			randomizer = new Random(now / 42);
		int i = 0;
		String salt = "";
		while (i < length)
		{
			salt += saltChars.charAt(randomizer.nextInt(saltChars.length()));
			i++;
		}
		return salt;
	}

	/**
     * Parses the algorithm name from the given hashed password's algorithm prefix.
	 * @param from_hashed_password a hashed password including the algorithm prefix.
	 * @return the algorithm specified in the given hashed password's algorithm prefix. null in case of any parsing error.
	 */
	public static String parseAlorithmName(String from_hashed_password)
	{
		if (from_hashed_password == null)
			return null;
		int left_idx = from_hashed_password.indexOf('{');
		if (left_idx != 0)
			return null;
		int right_idx = from_hashed_password.lastIndexOf('}');
		if (right_idx < 0)
			return null;
        if (right_idx - left_idx < 2)
            return null;
		String algo_name = from_hashed_password.substring(left_idx + 1,
				right_idx);
		return algo_name;
	}

}
