/***********************************************************
 * $Id: ThreadTimer.java 87 2007-12-17 01:06:40Z lech $
 * 
 * Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 2006-12-27
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.util.thread;

import java.util.TimerTask;

/**
 * @author andreas
 * 
 * Helper class for a timed thread execution. This class is called by the
 * {@link java.util.Timer} It invokes {@link #run()}, which starts the Thread.
 */
public class ThreadTimer extends TimerTask
{

	/**
	 * Thread to control
	 */
	private TimedThread _thread;

	/**
	 * if the thread is started this boolean is true
	 */
	private boolean started;

	/**
	 * composition to use the threadstopper
	 */
	private ThreadStopper stopper;

	/**
	 * contructes the object and sets the thread to run
	 * 
	 * @param thread
	 */
	public ThreadTimer(TimedThread thread)
	{
		this._thread = thread;
		this.started = false;
		this.stopper = new ThreadStopper();
		thread.setThreadTimer(this);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.util.TimerTask#run()
	 */
	@Override
	public void run()
	{
		if (!this.started)
		{
			((Thread) this._thread).start();
			this.started = true;
		} else
			this.stopper.resume();
	}

	/**
	 * 
	 */
	public void requestStop()
	{
		this.stopper.requestStop();

	}

	/**
	 * @return
	 */
	public boolean isToBeFinished()
	{
		return this.stopper.isToBeFinished();
	}

	/**
	 * @throws InterruptedException
	 * 
	 */
	public void waitToBeFinished() throws InterruptedException
	{
		this.stopper.waitToBeFinished();
	}

}
